@@ -1,6 +1,6 @@
-#' Collects municipal level data from the PETI (Child Slave Labour Erradication Program) database.
+#' Collects municipal level data from the PETI (Child Labour Erradication Program) database.
 #'
-#' PETI (Child Slave Labour Erradication Program) is a brazilian social welfare program that provides financial support for poor families. Its objective is to protect these families children from any type of work before the age of 16 years old, with that, the Federal Government expect them to keep going to school.
+#' PETI (Child Labour Erradication Program) is a brazilian social welfare program that provides financial support for poor families. Its objective is to protect these families children from any type of work before the age of 16 years old, with that, the Federal Government expect them to keep going to school.
 #' This function collects municipal level data from the program, some data like the number of citizens in a municipality which are enrolled in the program, and the total amount of money invested by the program in that city.
 #'
 #'
@@ -8,6 +8,7 @@
 #' @param AAAA Year of the Data (AAAA format)
 #' @param MM Month of the Data (MM format)
 #' @param PAGE Request's page. Default= 1.
+#' @param YEARLY If True, it is not needed to fill the MM param, the package will request the data for the entire year (AAAA). Default= TRUE.
 #'
 #'
 #' @return a tibble with the requested data, if there are more than one IBGECODE, returns all of them in the same tibble.
@@ -25,13 +26,15 @@
 #'   \item{tipo.descricaoDetalhada}{Full name of the program.}
 #' }
 #' @examples
-#' getpeti_mun("3304557", AAAA = "2015", MM = "05", PAGE = 1)
+#' \dontrun{
+#' getpeti_mun("3304557", AAAA = "2015", MM = "05", PAGE = 1, YEARLY=FALSE)
+#' }
 #' @author Joao Pedro Oliveira dos Santos, International Relations Institute, Pontifical Catholic University of Rio de Janeiro
 #'
 #' @export
 
 
-getpeti_mun <- function(IBGECODE, AAAA, MM, PAGE = 1) {
+getpeti_mun <- function(IBGECODE, AAAA, MM, PAGE = 1, YEARLY=TRUE) {
   if (AAAA < 1996) {
     stop("Invalid Input: PETI was created in 1996, so AAAA cannot be < 1996")
   }
@@ -46,26 +49,39 @@ getpeti_mun <- function(IBGECODE, AAAA, MM, PAGE = 1) {
 
   table <- c()
 
-  for (i in IBGECODE) {
-    request <- httr::GET(
-      url = path,
-      query = list(
-        mesAno = AAAAMM,
-        codigoIbge = i,
-        pagina = PAGEN
+
+  # loop para requerer os dados de cada municipio inserido; Requisição de um Mês específico.
+  if (YEARLY == FALSE) {
+    for (i in IBGECODE) { # API Request Code
+      request <- httr::GET(
+        url = path,
+        query = list(
+          mesAno = AAAAMM,
+          codigoIbge = i,
+          pagina = PAGEN
+        )
       )
-    )
 
-    if (request$status_code != 200) {
-      stop(warning("Request Failed: Status Code "), request$status_code)
+      if (request$status_code != 200) {
+        stop(warning("Request Failed: Status Code "), request$status_code) # In case of error, what to show?
+      }
+
+      # Transforma a resposta da API em texto, e então coloca-a em um DF, que depois é transformado em tibble.
+      resp <- httr::content(request, as = "text", encoding = "UTF-8")
+      newRow <- data.frame(jsonlite::fromJSON(resp, flatten = TRUE))
+
+      table <- dplyr::bind_rows(table, newRow)
+      table <- tibble::as_tibble(table)
     }
-
-    resp <- httr::content(request, as = "text", encoding = "UTF-8")
-    newRow <- data.frame(jsonlite::fromJSON(resp, flatten = TRUE))
-
-    table <- rbind(table, newRow)
-    table <- dplyr::as_tibble(table)
-  }
-
-  return(table)
+  } else
+    # Caso sejam feitas requisições de todos os meses de um ano, loop MM= 1 (janeiro) até 12 (dezembro).
+    if (YEARLY == TRUE) {
+      MX <- as.character(c("01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12")) # Quantity of Months
+      anos <- AAAA
+      for (i in MX) {
+        data <- getpeti_mun(IBGECODEN, anos, i, PAGEN, FALSE) # Recursion to avoid !DRY
+        table <- dplyr::bind_rows(table, data)
+      }
+    }
+  return(tibble::as_tibble(table))
 }
